@@ -1,7 +1,7 @@
 from typing import List, Optional, Dict
 
 from dataclasses import dataclass, field
-from code_loader.contract.enums import DatasetMetadataType, LeapDataType, MetricEnum
+from code_loader.contract.enums import DatasetMetadataType, LeapDataType
 
 
 @dataclass
@@ -45,6 +45,12 @@ class MetricInstance:
     arg_names: List[str]
 
 
+@dataclass
+class CustomLossInstance:
+    name: str
+    arg_names: List[str]
+
+
 @dataclass
 class CustomLayerInstance:
     name: str
@@ -56,8 +62,6 @@ class CustomLayerInstance:
 class PredictionTypeInstance:
     name: str
     labels: List[str]
-    metrics: Optional[List[MetricEnum]] = None
-    custom_metrics: Optional[List[str]] = None
 
 
 @dataclass
@@ -68,7 +72,7 @@ class DatasetSetup:
     outputs: List[DatasetOutputInstance]
     visualizers: List[VisualizerInstance]
     prediction_types: List[PredictionTypeInstance]
-    custom_loss_names: List[str]
+    custom_losses: List[CustomLossInstance]
     metrics: List[MetricInstance] = field(default_factory=list)
 
 
@@ -83,6 +87,8 @@ class DatasetTestResultPayload:
     display: Dict[str, str] = field(default_factory=dict)
     is_passed: bool = True
     shape: Optional[List[int]] = None
+    raw_result = None
+    handler_type = None
 
 
 @dataclass
@@ -105,3 +111,4 @@ class DatasetIntegParseResult:
     setup: Optional[DatasetSetup] = None
     model_setup: Optional[ModelSetup] = None
     general_error: Optional[str] = None
+    print_log: Optional[str] = None
